@@ -1,4 +1,6 @@
 # -*- coding: utf-8 -*-
+import warnings
+
 from urlparse import urlparse
 
 from django.db import models
@@ -34,12 +36,6 @@ class Post(Article):
         related_name='post_albums',
         verbose_name=_(u"Albums")
     )
-    related_posts = models.ManyToManyField(
-        'containers.Container',
-        null=True, blank=True,
-        related_name='post_relatedposts',
-        through='articles.PostRelated',
-    )
 
     objects = PublishableManager()
 
@@ -99,6 +95,12 @@ class Post(Article):
             'postrelated_related__order'
         ).distinct()
 
+    @property
+    def related_posts(self):
+        warn = "related_posts will be removed, must use related_containers."
+        warnings.warn(warn, DeprecationWarning)
+        return self.related_containers
+
 
 class PostRelated(models.Model):
 
