@@ -6,6 +6,7 @@ from django.contrib.sitemaps import views as sitemap_views
 from opps.core.cache import cache_page
 
 from opps.sitemaps.sitemaps import GenericSitemap, InfoDict
+from opps.sitemaps.views import sitemap
 
 sitemaps = {
     'containers': GenericSitemap(InfoDict(), priority=0.6),
@@ -20,7 +21,7 @@ urlpatterns = patterns(
     url(r'^\.xml$', cache_page(86400)(sitemap_views.index),
         {'sitemaps': sitemaps, 'sitemap_url_name': 'sitemaps'},),
     url(r'^-googlenews\.xml$',
-        cache_page(86400)(sitemap_views.sitemap),
+        cache_page(86400)(sitemap),
         {'sitemaps': sitemaps_googlenews,
          'template_name': 'sitemap_googlenews.xml'}),
     url(r'^-(?P<section>.+)\.xml$',
